# Thermalift

**Calculator for eliminating the thermal lift effect from production data in geothermal wells.**

Thermalift was developed as part of the [GeoModel](https://geomodel.pl/en/) project.

The user's guide can be found in the docs directory or [here](https://github.com/maciejmiecznik/thermalift/blob/main/docs/Thermalift_1.0_user_guide.pdf)


The output from Thermalift calculator can be a figure similar to the below one, showing how thermal lift influences the observed water table level or water table drawdown.

![Thermalft output figure](https://github.com/maciejmiecznik/thermalift/blob/main/examples/Case%20ST/Test%20well%20raw%20and%20corrected%20pumping%20data_thermal_lift.png?raw=true)


Thermalift is a part of project "Optimal management of low-temperature geothermal reservoirs – Polish-Icelandic cooperation on reservoir modelling" (acronym GeoModel), financed under the Fund for Bilateral Relations through the [European Economic Area Financial Mechanism (EEA FM) and the Norwegian Financial Mechanism (NFM)](https://eeagrants.org/) 2014-2021 under the Environment, Energy and Climate Change Programme.
